Index: /sites/trunk/wordpress.org/public_html/wp-content/plugins/plugin-directory/class-plugin-directory.php
===================================================================
--- /sites/trunk/wordpress.org/public_html/wp-content/plugins/plugin-directory/class-plugin-directory.php	(revision 5333)
+++ /sites/trunk/wordpress.org/public_html/wp-content/plugins/plugin-directory/class-plugin-directory.php	(revision 5334)
@@ -1233,5 +1233,5 @@
 	 *     @type string $post_title            The post title. Default empty.
 	 *     @type string $post_excerpt          The post excerpt. Default empty.
-	 *     @type string $post_status           The post status. Default 'draft'.
+	 *     @type string $post_status           The post status. Default 'new'.
 	 *     @type string $post_type             The post type. Default 'post'.
 	 *     @type string $comment_status        Whether the post can accept comments. Accepts 'open' or 'closed'.

Index: /sites/trunk/wordpress.org/public_html/wp-content/plugins/plugin-directory/admin/tools/class-stats-report.php
===================================================================
--- /sites/trunk/wordpress.org/public_html/wp-content/plugins/plugin-directory/admin/tools/class-stats-report.php	(revision 5333)
+++ /sites/trunk/wordpress.org/public_html/wp-content/plugins/plugin-directory/admin/tools/class-stats-report.php	(revision 5334)
@@ -56,7 +56,7 @@
 	 *     @type int $plugin_new                         The number of plugins submitted within the defined time interval.
 	 *     @type int $plugin_reject                      The number of plugins rejected within the defined time interval.
 	 *     @type int $in_queue                           The number of plugins currently in the queue (draft or pending).
 	 *     @type int $in_queue_draft                     The number of draft plugins currently in the queue.
 	 *     @type int $in_queue_oending                   The number of pending plugins currently in the queue.
 	 *     @type int $in_queue_from_time_window          The number of plugins currently in the queue submitted during the specified time window.
 	 *     @type int $in_queue_old                       The number of plugins currently in the queue that are older than "recently".
@@ -106,6 +106,6 @@
 		// --------------
 
-		// # of plugins currently in the queue that are drafts (have not been processed/replied to yet)
-		$stats['in_queue_draft'] = $wpdb->get_var(
+		// # of plugins currently in the queue that are new (have not been processed/replied to yet)
+		$stats['in_queue_new'] = $wpdb->get_var(
 			"SELECT COUNT(*) FROM $wpdb->posts WHERE `post_type` = 'plugin' AND `post_status` = 'new'"
 		);
@@ -116,6 +116,6 @@
 		);
 
-		// # of plugins currently in the queue (draft + pending)
-		$stats['in_queue'] = $stats['in_queue_draft'] + $stats['in_queue_pending'];
+		// # of plugins currently in the queue (new + pending)
+		$stats['in_queue'] = $stats['in_queue_new'] + $stats['in_queue_pending'];
 
 		// # of plugins currently in the queue submitted during the specified time window
@@ -246,8 +246,8 @@
 
 		<ul style="font-family:Courier New;">
-			<li><?php printf( __( 'Plugins in the queue (draft and pending)* : %d', 'wporg-plugins' ), $stats['in_queue'] ); ?></li>
+			<li><?php printf( __( 'Plugins in the queue (new and pending)* : %d', 'wporg-plugins' ), $stats['in_queue'] ); ?></li>
 			<li><?php printf( __( '&rarr; (older than %1$d days ago)** : %2$d', 'wporg-plugins' ), $stats['recentdays'], $stats['in_queue_old'] ); ?></li>
 			<li><?php printf( __( '&rarr; (%1$s - %2$s) : %3$d', 'wporg-plugins' ), $start_date, $stats['date'], $stats['in_queue_from_time_window'] ); ?></li>
-			<li><?php printf( __( '&rarr; (drafts; not processed or replied to yet)* : %d', 'wporg-plugins' ), $stats['in_queue_draft'] ); ?></li>
+			<li><?php printf( __( '&rarr; (new; not processed or replied to yet)* : %d', 'wporg-plugins' ), $stats['in_queue_new'] ); ?></li>
 			<li><?php printf( __( '&rarr; (pending; replied to)* : %d', 'wporg-plugins' ), $stats['in_queue_pending'] ); ?></li>
 		</ul>
@@ -56,7 +56,7 @@
 	 *     @type int $plugin_new                         The number of plugins submitted within the defined time interval.
 	 *     @type int $plugin_reject                      The number of plugins rejected within the defined time interval.
-	 *     @type int $in_queue                           The number of plugins currently in the queue (draft or pending).
-	 *     @type int $in_queue_draft                     The number of draft plugins currently in the queue.
-	 *     @type int $in_queue_oending                   The number of pending plugins currently in the queue.
+	 *     @type int $in_queue                           The number of plugins currently in the queue (new or pending).
+	 *     @type int $in_queue_new                       The number of new plugins currently in the queue.
+	 *     @type int $in_queue_pending                   The number of pending plugins currently in the queue.
 	 *     @type int $in_queue_from_time_window          The number of plugins currently in the queue submitted during the specified time window.
 	 *     @type int $in_queue_old                       The number of plugins currently in the queue that are older than "recently".